use crate::html_parser::{parse_inner_node, replace_html_codes};

#[derive(Clone, PartialEq, Eq)]
pub struct RemainingPlace {
    pub id: String,
    pub description: String,
    pub date: String,
    pub free: usize,
}

pub fn get_current_places(url: &str) -> Result<Vec<RemainingPlace>, reqwest::Error> {
    let body = reqwest::blocking::get(url)?.text()?;

    let start = body.find("<tbody").unwrap();
    let end = body.find("</tbody>").unwrap();

    let table = &body[start..=(end + 7)];

    let mut places: Vec<RemainingPlace> = Vec::new();
    let mut lines: Vec<String> = Vec::new();

    let mut line = table.replace("\n", "").replace("\r", "");

    while let Some(begin) = line.find("<td") {
        match line.find("</td>") {
            Some(end) => {
                let inner_node = &line[(begin + 5)..end];
                let content = parse_inner_node(inner_node);
                let escaped_content = replace_html_codes(&content);

                lines.push(escaped_content);
                line.replace_range(begin..=end + 5, "");
            }
            None => break,
        }
    }

    lines.chunks(4).for_each(|chunk| {
        let new_remaining_place = RemainingPlace {
            id: chunk[0].clone(),
            description: chunk[1].clone(),
            date: chunk[2].clone(),
            free: match chunk[3].parse() {
                Ok(value) => value,
                Err(_) => 0,
            },
        };

        places.push(new_remaining_place);
    });

    Ok(places)
}
